Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3159)

Unified Diff: blimp/common/compositor/blimp_task_graph_runner.h

Issue 1449133002: TaskGraphRunner refactor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: feedback Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/threading/thread_restrictions.h ('k') | blimp/common/compositor/blimp_task_graph_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: blimp/common/compositor/blimp_task_graph_runner.h
diff --git a/blimp/common/compositor/blimp_task_graph_runner.h b/blimp/common/compositor/blimp_task_graph_runner.h
index 666f743bd11218d167a16b3ba8324c00fdb3292c..084f3979479ef97fe664b84f907698ecd0417c7e 100644
--- a/blimp/common/compositor/blimp_task_graph_runner.h
+++ b/blimp/common/compositor/blimp_task_graph_runner.h
@@ -8,25 +8,20 @@
#include "base/macros.h"
#include "base/threading/simple_thread.h"
#include "blimp/common/blimp_common_export.h"
-#include "cc/raster/task_graph_runner.h"
+#include "cc/raster/single_thread_task_graph_runner.h"
namespace blimp {
// TaskGraphRunner that runs on a single thread. See cc::TaskGraphRunner for
// details. Used by client's compositor and engine's dummy UI context factory.
class BLIMP_COMMON_EXPORT BlimpTaskGraphRunner
- : public cc::TaskGraphRunner,
- public base::DelegateSimpleThread::Delegate {
+ : public cc::SingleThreadTaskGraphRunner {
public:
BlimpTaskGraphRunner();
~BlimpTaskGraphRunner() override;
private:
- // base::DelegateSimpleThread::Delegate implementation.
- void Run() override;
-
- base::DelegateSimpleThread worker_thread_;
-
DISALLOW_COPY_AND_ASSIGN(BlimpTaskGraphRunner);
};
« no previous file with comments | « base/threading/thread_restrictions.h ('k') | blimp/common/compositor/blimp_task_graph_runner.cc » ('j') | no next file with comments »
@@ -8,25 +8,20 @@
namespace blimp {
-// TaskGraphRunner that runs on a single thread. See cc::TaskGraphRunner for
-// details. Used by client's compositor and engine's dummy UI context factory.
+// TaskGraphRunner that runs on a single thread. See
+// cc::SingleThreadTaskGraphRunner for details. Used by client's compositor and
+// engine's dummy UI context factory.
class BLIMP_COMMON_EXPORT BlimpTaskGraphRunner

Powered by Google App Engine
This is Rietveld 408576698